****************************************************************
**Using time series on real income based on the Maddison Project
**Economic_inequality_ts.csv
****************************************************************

tsset year
tsline coeffvar_g77 coeffvar_g77nooil coeffvar_oecd, lcolor(red maroon navy) legend(order(1 "G77" 2 "G77 (exc. oil)" 3 "OECD")) ytitle(Coefficient of Variation)
tsline pc25_cgdppc_oecd pc50_cgdppc_oecd pc75_cgdppc_oecd pc25_cgdppc_g77china pc50_cgdppc_g77china pc75_cgdppc_g77china, lpattern(dash solid dash dash solid dash) legend(order(2 "OECD" 5 "G77")) lcolor(navy navy navy red red red) ytitle(US$ pc PPP)


****************************************************************
**Using income ranking data based on the Maddison Project
**Rank_inequality.csv
****************************************************************

egen rank1980 = rank(-cgdppc1980)

egen rank2015 = rank(-cgdppc2015)


**Two-sample Wilcoxon rank-sum (not reported in the paper)
ranksum rank2015, by(g77_1980_china)
ranksum rank1980, by(g77_1980_china)

**Measures of consistency of rankings
spearman rank1980 rank2015
ktau rank1980 rank2015

**Calculate change in ranking for each state
gen change = rank1980-rank2015

**Summary statistics for rank incomes
by g77_1980_china, sort : summarize rank1980 rank2015 change, detail

**Histograms - for visualisation, not reported in article
**histogram change if g77_1980_china==1, kdensity xtitle(Change in Income Ranking 1980 to 2015 - G77) xlabel(-60 -30 0 30 60)
**histogram change if g77_1980_china==0, kdensity xtitle(Change in Income Ranking 1980 to 2015 - OECD) xlabel(-60 -30 0 30 60)

**Normality of the distribution of changes in ranking G77, OECD
swilk change if g77_1980_china == 1

swilk change if g77_1980_china == 0


**Create a scatter diagram of the income ranking of countries in 1980 and 2015
twoway (scatter rank2015 rank1980 if g77_1980_china ==0, msymbol(X)) (scatter rank2015 rank1980 if g77_1980_china ==1) (function y = x, range(129 1)), xsc(reverse) ysc(reverse) legend(label(1 OECD) label(2 G77) label (3 Line of Equality)) ytitle(Income Rank 2015) xtitle(Income Rank 1980) ylabel(1 44 87 129) xlabel(1 44 87 129)

**Other descriptive statistics were calculated by hand


****************************************************************
**Using economic power (GDP) data from the World Bank
**Economic_power_ts.csv
****************************************************************

tsset year
tsline g77_prop_oecd g77china_prop_oecd, legend(label(1 G77) label(2 G77 & China)) ylabel(0 0.2 0.4 0.6 0.8) ytitle(Nominal GDP as proportion of OECD nominal GDP) lpattern(longdash dash)
**Install the multiline package if not installed
**ssc desc multiline
** ssc install multiline
multiline oecd_prop g77_prop china_prop year, xtitle("") mylabels(OECD G77 China)

**Alternatively
tsline g77_prop china_prop oecd_prop, legend(label(1 G77) label(2 China) label(3 OECD)) ytitle(Proportion of World nominal GDP) lpattern(longdash dash dash_dot)

****************************************************************
**Using panel data on UN ideal points from Bailey, Strezhnev and Voeten 
**Unideal_panel.csv
****************************************************************


**T-tests in both years
ttest idealpoint if year ==1980, by(g77china) unequal welch

ttest idealpoint if year ==2018, by(g77china) unequal welch

**Robust test of equal variances
robvar idealpoint if year==1980, by(g77china)
robvar idealpoint if year==2018, by(g77china)
robvar idealpoint if (g77china == 1) & ((year ==1980)  |  (year == 2018)), by(year)

**Generate data for subsequent time series analysis

**generate SDs for UN groupings by distance from US

egen SDdist_g77 = sd(dist_us), by(g77china year)
egen SDdist_oecd = sd(dist_us), by(oecd year)
egen SDdist_oecd_nonus = sd(dist_us), by(oecd_nonus year)

****generate SDs for UN groupings by idealpoint

egen SDideal_g77 = sd(idealpoint), by(g77china year)
egen SDideal_oecd = sd(idealpoint), by(oecd year)
egen SDideal_oecd_nonus = sd(idealpoint), by(oecd_nonus year)

****generate MEANs for UN groupings by distance from the US

egen MEANdist_g77 = mean(dist_us), by(g77china year)
egen MEANdist_oecd = mean(dist_us), by(oecd year)
egen MEANdist_oecd_nonus = mean(dist_us), by(oecd_nonus year)

****generate MEANs for UN groupings by idealpoint

egen MEANideal_g77 = mean(idealpoint), by(g77china year)
egen MEANideal_oecd = mean(idealpoint), by(oecd year)
egen MEANideal_oecd_nonus = mean(idealpoint), by(oecd_nonus year)
egen MEANideal_g77nobrics = mean(idealpoint), by(g77nobrics year)

**Percentiles

egen pc25_ideal_oecd = pctile(idealpoint), p(25) by(oecd year)
egen pc50_ideal_oecd = pctile(idealpoint), p(50) by(oecd year)
egen pc75_ideal_oecd = pctile(idealpoint), p(75) by(oecd year)

egen pc25_ideal_oecd_nonus = pctile(idealpoint), p(25) by(oecd_nonus year)
egen pc50_ideal_oecd_nonus = pctile(idealpoint), p(50) by(oecd_nonus year)
egen pc75_ideal_oecd_nonus = pctile(idealpoint), p(75) by(oecd_nonus year)

egen pc25_ideal_G77 = pctile(idealpoint), p(25) by(g77china year)
egen pc50_ideal_G77 = pctile(idealpoint), p(50) by(g77china year)
egen pc75_ideal_G77 = pctile(idealpoint), p(75) by(g77china year)

egen pc25_dist_oecd = pctile(dist_us), p(25) by(oecd year)
egen pc50_dist_oecd = pctile(dist_us), p(50) by(oecd year)
egen pc75_dist_oecd = pctile(dist_us), p(75) by(oecd year)

egen pc25_dist_oecd_nonus = pctile(dist_us), p(25) by(oecd_nonus year)
egen pc50_dist_oecd_nonus = pctile(dist_us), p(50) by(oecd_nonus year)
egen pc75_dist_oecd_nonus = pctile(dist_us), p(75) by(oecd_nonus year)

egen pc25_dist_G77 = pctile(dist_us), p(25) by(g77china year)
egen pc50_dist_G77 = pctile(dist_us), p(50) by(g77china year)
egen pc75_dist_G77 = pctile(dist_us), p(75) by(g77china year)

****************************************************************
**Using time series of UN similarity
**Unideal_ts.csv
****************************************************************


tsset year

tsline sdideal_oecd sdideal_g77 if year >1963, legend(order(1 "OECD" 2 "G77")) lpattern(solid longdash) ytitle(Standard Deviation of Ideal Points)

tsline  pc25_dist_oecd_nonus pc50_dist_oecd_nonus pc75_dist_oecd_nonus pc25_dist_g77 pc50_dist_g77 pc75_dist_g77 if year >1963, legend(order(2 "OECD" 5 "G77")) lpattern(dash solid dash dash solid dash) lcolor(navy navy navy red red red) ytitle(Median Distances from US Ideal Point)

tsline meanideal_g77nobrics brazil china india southafrica if year >1980, legend(order(1 "G77" 2 "Brazil" 3 "China" 4 "India" 5 "South Africa")) lpattern(solid dash longdash dash_dot dash) lcolor(red green maroon orange blue) ytitle(Ideal Points)


***All calculations performed using Stata v.14.1
